<?php
/* --------------------------------------------------------------
  AbstractContentManagerOption.php 2019-08-02
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2019 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

namespace Gambio\StyleEdit\Core\Components\ContentManager\Entities;

use ContentNotFoundException;
use ContentReadServiceInterface;
use ContentText;
use Gambio\StyleEdit\Core\Language;
use Gambio\StyleEdit\Core\Options\Entities\AbstractComponentOption;
use Gambio\StyleEdit\Core\Options\Entities\ComponentOptionAttribute;
use Gambio\StyleEdit\Core\SingletonPrototype;
use Gambio\StyleEdit\Core\Components\ContentManager\Interfaces\ContentManagerOptionValueInterface;
use Gambio\StyleEdit\Core\Components\Wysiwyg\Entities\WysiwygOptionValue;
use InfoElementContent;
use ReflectionException;

/**
 * Class AbstractContentManagerOption
 */
abstract class AbstractContentManagerOption extends AbstractComponentOption
{
    /**
     * @var int
     */
    protected $contentGroup;
    
    /**
     * @var boolean
     */
    protected $useEditorContent;
    
    
    /**
     * @param $value
     *
     * @return boolean
     */
    protected function isValid($value): bool
    {
        return $this->translatable() ? is_object($value) && !isset($value->id) : is_object($value);
    }
    
    
    /**
     * @param $object
     *
     * @throws ReflectionException
     */
    public function initializeFromJsonObject($object): void
    {
        if (isset($object->label)) {
            $this->label = $object->label;
        }
        
        if (isset($object->attributes)) {
            foreach ($object->attributes as $key => $attribute) {
                $this->attributes->setValue($key, ComponentOptionAttribute::create($key, $attribute));
            }
            $this->label = $object->label;
        }
        
        if (isset($object->default)) {
            $this->default = $object->default;
        }
        
        if (isset($object->contentGroup)) {
            $this->contentGroup = (int)$object->contentGroup;
        }
        
        if (isset($object->translatable)) {
            $this->translatable = $object->translatable === true;
        }
        
        if (isset($object->useEditorContent)) {
            $this->useEditorContent = (bool)$object->useEditorContent;
        }
        
        if (isset($object->value) && $this->isValid($object->value)) {
            $this->value = $this->parseValue($object->value);
        }
        
        if (!isset($object->value) && isset($object->id)) {
            
            /** @var ContentReadServiceInterface $reader */
            $reader                    = SingletonPrototype::instance()->get(ContentReadServiceInterface::class);
            $contentManagerEntry       = null;
            $contentManagerEntryExists = true;
            
            try {
                $contentManagerEntry = $reader->findById($this->contentGroup);
            } catch (ContentNotFoundException $contentNotFoundException) {
                $contentManagerEntryExists = false;
            }
            
            if ($contentManagerEntryExists) {
                $this->value = [];
                /** @var InfoElementContent $value */
                foreach ($contentManagerEntry->texts() as $text) {
                    
                    /** @var ContentText $text */
                    $this->value[$text->languageCode()] = $text->content();
                }
            } else {
                
                $this->value = $this->default;
            }
        }
        
        if (isset($object->id)) {
            $this->id = $object->id;
        }
        
        if (isset($object->selector)) {
            $this->selector = $object->selector;
        }
        
        if (isset($object->for)) {
            $this->for = $object->for;
        }
    }
    
    
    /**
     * @return int
     */
    public function contentGroup(): ?int
    {
        return $this->contentGroup;
    }
    
    
    /**
     * @param int $contentGroup
     */
    public function setContentGroup(int $contentGroup): void
    {
        $this->contentGroup = $contentGroup;
    }
    
    
    /**
     * @return mixed
     */
    public function jsonSerialize()
    {
        $result                   = parent::jsonSerialize();
        $result->contentGroup     = $this->contentGroup();
        $result->useEditorContent = $this->useEditorContent;
        
        return $result;
    }
    
    
    /**
     * @return bool
     */
    public function useEditorContent(): bool
    {
        return $this->useEditorContent;
    }
}