<?php
/* --------------------------------------------------------------
  SingletonPublicCacheClearer.php 2019-09-06
  Gambio GmbH
  http://www.gambio.de
  Copyright (c) 2019 Gambio GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------*/

namespace Gambio\StyleEdit\Core\Components\ContentZone\Utility;

use Exception;
use Gambio\StyleEdit\Core\Components\Theme\StyleEditThemeService;

/**
 * Class SingletonPublicCacheClearer
 *
 * This class is used to prevent premature clearing of the public cache.
 *
 * After a request to the api (for example ContentZoneSaveCommand)
 * it calls the static method and after the script was fulfilled
 * the public directory is cleared.
 *
 * Since this class is a Singleton it can only be initiated once.
 */
class SingletonPublicCacheClearer
{
    /**
     * @var StyleEditThemeService
     */
    protected $themeService;
    
    /**
     * @var SingletonPublicCacheClearer
     */
    protected static $instance;
    
    
    /**
     * SingletonPublicCacheClearer constructor.
     *
     * @param StyleEditThemeService $themeService
     */
    final protected function __construct(StyleEditThemeService $themeService)
    {
        $this->themeService = $themeService;
    }
    
    
    /**
     * @param StyleEditThemeService $themeService
     *
     * @return SingletonPublicCacheClearer
     */
    public static function instance(StyleEditThemeService $themeService): self
    {
        if (self::$instance === null) {
            
            self::$instance = new static($themeService);
        }
        
        return self::$instance;
    }
    
    
    /**
     * @throws Exception
     */
    public function __destruct()
    {
        $this->themeService->clearPublishedTheme(true);
    }
}