<?php
/* --------------------------------------------------------------
   BasicElement.inc.php 2019-03-14
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

namespace Gambio\StyleEdit\Core\Components\Variant\Commands;

use Exception;
use Gambio\StyleEdit\Core\Command\CommandInterface;
use Gambio\StyleEdit\Core\Components\Variant\Entities\VariantOption;
use Gambio\StyleEdit\Core\Options\Commands\AbstractSaveCommand;
use Gambio\StyleEdit\Core\Options\Entities\OptionInterface;
use Gambio\StyleEdit\Core\Repositories\ConfigurationRepository;
use Gambio\StyleEdit\Core\SingletonPrototype;
use Gambio\StyleEdit\Core\Components\Theme\StyleEditThemeService;
use Gambio\StyleEdit\Core\Components\Variant\Services\VariantService;

/**
 * Class VariantSaveCommand
 * @package Gambio\StyleEdit\Core\Components\Variant\Commands
 */
class VariantSaveCommand extends AbstractSaveCommand implements CommandInterface
{
    
    /**
     * @var \Gambio\StyleEdit\Core\Components\Variant\Services\VariantService
     */
    protected $receiver;
    
    /**
     * @var StyleEditThemeService
     */
    protected $themeService;
    
    
    /**
     * Execute the command
     */
    function execute(): void
    {
        $this->themeService()->clearPublishedTheme();
        $this->saveOption();
        
        if (is_a($this->option, VariantOption::class)) {
            
            ConfigurationRepository::instance()->restoreVariantSettings($this->option);
        }
    }
    
    
    /**
     * @return \Gambio\StyleEdit\Core\Components\Variant\Services\VariantService
     * @throws \Exception
     */
    private function getReceiver(): VariantService
    {
        if ($this->receiver === null) {
            $this->receiver = SingletonPrototype::instance()->get(VariantService::class);
            if (!$this->receiver) {
                throw new Exception('VariantService was not initialized');
            }
        }
        
        return $this->receiver;
    }
    
    
    /**
     * @return StyleEditThemeService
     * @throws Exception
     */
    private function themeService(): StyleEditThemeService
    {
        if ($this->receiver === null) {
            $this->receiver = SingletonPrototype::instance()->get(StyleEditThemeService::class);
            if (!$this->receiver) {
                throw new Exception('StyleEditThemeService was not initialized');
            }
        }
        
        return $this->receiver;
    }
    
    
    /**
     * Execute the command
     */
    public function rollback(): void
    {
        // TODO: Implement rollback() method.
    }
}