<?php

namespace Gambio\StyleEdit\Core\Options\Commands;

use Gambio\StyleEdit\Core\Command\CommandInterface;
use Gambio\StyleEdit\Core\Options\Entities\AbstractOption;
use Gambio\StyleEdit\Core\Options\Entities\OptionInterface;
use Gambio\StyleEdit\Core\Repositories\ConfigurationRepository;
use Gambio\StyleEdit\Core\SingletonPrototype;

/**
 * Class BasicOptionSaveAction
 * @package Gambio\StyleEdit\Core\Options
 */
abstract class AbstractSaveCommand implements CommandInterface
{
    /**
     * @var AbstractOption
     */
    protected $option;
    /**
     * @var ConfigurationRepository
     */
    private $configurationRepository;
    
    
    /**
     * Execute the command
     */
    abstract public function execute(): void;
    
    
    /**
     * Execute the command
     */
    abstract public function rollback(): void;
    
    
    /**
     * @param OptionInterface $option
     */
    public function setOption(OptionInterface $option): void
    {
        $this->option = $option;
    }
    
    
    /**
     * @throws \Exception
     */
    protected function saveOption(): void
    {
        $this->configurationRepository()->saveOptionToConfiguration($this->option);
    }
    
    
    /**
     * @param ConfigurationRepository $configurationRepository
     */
    public function setConfigurationRepository(ConfigurationRepository $configurationRepository): void
    {
        $this->configurationRepository = $configurationRepository;
    }
    
    
    /**
     * @return ConfigurationRepository
     * @throws \Exception
     */
    protected function configurationRepository(): ConfigurationRepository
    {
        if ($this->configurationRepository === null) {
            $this->configurationRepository = SingletonPrototype::instance()->get(ConfigurationRepository::class);
        }
        
        return $this->configurationRepository;
    }
    
    
}