<?php
/* --------------------------------------------------------------
   SettingsController.php 2019-04-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

namespace Gambio\StyleEdit\Core\Options\Entities;

use Exception;
use Gambio\StyleEdit\Core\Components\Variant\Services\VariantService;
use Gambio\StyleEdit\Core\Repositories\ConfigurationRepository;
use Gambio\StyleEdit\Core\SingletonPrototype;
use Gambio\StyleEdit\Core\Components\Option\Entities\Option;
use Gambio\StyleEdit\Core\Components\Option\Entities\OptionCollection;

/**
 * Class FieldSet
 * @package Gambio\StyleEdit\Core\Components\Entities
 */
class FieldSet extends AbstractConfigurationType
{
    
    /**
     * @var \Gambio\StyleEdit\Core\Components\Entities\Options\OptionCollection
     *
     */
    protected $options;
    
    protected $configurationRepository;
    
    
    public function __construct()
    {
        $this->options = new OptionCollection();
    }
    
    
    /**
     * @param                              $jsonFieldSet
     *
     * @param ConfigurationRepository|null $configurationRepository
     *
     * @return bool|mixed
     * @throws \ReflectionException
     * @throws Exception
     */
    public static function createFromJsonObject($jsonFieldSet, ConfigurationRepository $configurationRepository = null)
    {
        $result = SingletonPrototype::instance()->get(FieldSet::class);
        if (!$result instanceof self) {
            throw new Exception('FieldSet instance must inherit ' . self::class . '!');
        }
        $result->configurationRepository = $configurationRepository;
        $result->initializeFromJsonObject($jsonFieldSet, $configurationRepository);
        
        return $result;
    }
    
    
    /**
     * @param                              $object
     *
     * @param VariantService               $variantService
     * @param ConfigurationRepository|null $configurationRepository
     *
     * @throws Exception
     */
    public function initializeFromJsonObject($object): void
    {
        parent::initializeFromJsonObject($object);
        if (!isset($object->options) || !is_array($object->options)) {
            throw new Exception('FieldSet must a valid options list!');
        }
        foreach ($object->options as $option) {
            $this->options->addItem(Option::createFromJsonObject($option, '', $this->configurationRepository));
        }
    }
    
    
    /**
     * @return \Gambio\StyleEdit\Core\Components\Entities\Options\OptionCollection
     */
    public function options(): OptionCollection
    {
        return $this->options;
    }
    
    
    /**
     * Specify data which should be serialized to JSON
     * @link  https://php.net/manual/en/jsonserializable.jsonserialize.php
     * @return mixed data which can be serialized by <b>json_encode</b>,
     * which is a value of any type other than a resource.
     * @since 5.4.0
     */
    public function jsonSerialize()
    {
        $result = [];
        if ($this->id()) {
            $result['id'] = $this->id();
        }
        
        if ($this->title()) {
            $result['title'] = $this->title();
        }
        
        if ($this->type()) {
            $result['type'] = $this->type();
        }
        
        if (count($this->options)) {
            $result['options'] = [];
            foreach ($this->options as $option) {
                $result['options'][] = $option;
            }
        }
        
        return (object)$result;
    }
    
    
    public function __clone()
    {
        $this->options = clone $this->options;
    }
}
