<?php
/* --------------------------------------------------------------
   BasicElement.inc.php 2019-04-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

namespace Gambio\StyleEdit\Core\Repositories;

use Exception;
use Gambio\StyleEdit\Core\InvalidDirectoryException;
use Gambio\StyleEdit\Core\JsonFileIO;
use Gambio\StyleEdit\Core\SingletonPrototype;
use Gambio\StyleEdit\Core\TranslatedException;
use Gambio\StyleEdit\StyleEditConfiguration;
use ReflectionException;
use RuntimeException;
use stdClass;

/**
 * Class BasicThemeRepository
 * @package Gambio\StyleEdit\Core\Components\Theme
 */
class BasicFileRepository
{
    /**
     * @var StyleEditConfiguration
     */
    private $configuration;
    
    /**
     * @var JsonFileIO
     */
    private $jsonFileIO;
    
    
    /**
     * @return StyleEditConfiguration
     * @throws ReflectionException
     * @throws RuntimeException
     */
    protected function configuration(): StyleEditConfiguration
    {
        
        if ($this->configuration === null) {
            $this->configuration = SingletonPrototype::instance()->get(StyleEditConfiguration::class);
            if (!$this->configuration) {
                throw new RuntimeException('StyleEditConfiguration was not initialized');
            }
        }
        
        return $this->configuration;
    }
    
    
    /**
     * @param $filePath
     *
     * @return array|mixed
     * @throws Exception
     * @throws RuntimeException
     */
    protected function loadJsonFilesFromDisk($filePath)
    {
        $jsonObject = $this->jsonFileIO()->read($filePath);
        
        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new RuntimeException("Invalid Json file '$filePath'" . json_last_error_msg());
        }
        
        return $jsonObject;
    }
    
    
    /**
     * @param $object
     * @param $filePath
     *
     * @return bool|int
     * @throws Exception
     */
    protected function saveJsonFilesToDisk($object, $filePath)
    {
        return $this->jsonFileIO()->write($object, $filePath);
    }
    
    
    /**
     * @param $filePath
     *
     * @return array|mixed
     * @throws TranslatedException
     */
    protected function loadConfigFromDisk($filePath): stdClass
    {
        $themeJsonPath = $filePath . DIRECTORY_SEPARATOR . 'theme.json';
        $themeConfig   = $this->jsonFileIO()->read($themeJsonPath);
        
        if (json_last_error() !== JSON_ERROR_NONE || get_class($themeConfig) !== 'stdClass') {
            throw new TranslatedException('THEME_WITHOUT_CONFIGURATION', [$filePath, json_last_error_msg()]);
        }
        
        return $themeConfig;
    }
    
    
    /**
     * @return JsonFileIO
     * @throws Exception
     */
    protected function jsonFileIO(): JsonFileIO
    {
        if ($this->jsonFileIO === null) {
            $this->jsonFileIO = SingletonPrototype::instance()->get(JsonFileIO::class);
            if (!$this->jsonFileIO) {
                throw new RuntimeException('JsonFileIO was not initialized');
            }
        }
        
        return $this->jsonFileIO;
    }
    
    
    /**
     * @param $config
     * @param $themePath
     *
     * @throws Exception
     */
    protected function saveConfigToDisk($config, $themePath): void
    {
        $filePath = $themePath . DIRECTORY_SEPARATOR . 'theme.json';
        $this->jsonFileIO()->write($config, $filePath);
    }
    
    
}